@@ -11,12 +11,13 @@
 
 raise "sorry, 1.8 was last decade" unless RUBY_VERSION >= '1.9'
 
-gem 'kramdown', '~> 1.8.0'
+gem 'kramdown', '~> 1.10.0'
 require 'kramdown'
 my_span_elements =  %w{list figure xref eref iref cref spanx vspace}
 Kramdown::Parser::Html::Constants::HTML_SPAN_ELEMENTS.concat my_span_elements
 
 require 'rexml/parsers/baseparser'
+require 'open3'                 # for math
 
 class Object
   def deep_clone
@@ -290,7 +291,8 @@ module Kramdown
         @in_dt = 1
         vspace = opts[:vspace]
         vspaceel = "<vspace blankLines='#{vspace}'/>" if vspace
-        "#{close}#{' '*indent}<t#{el_html_attributes(el)} hangText='#{inner(el, indent, opts)}'>#{vspaceel}\n"
+        ht = escape_html(inner(el, indent, opts), :attribute) # XXX this may leave gunk
+        "#{close}#{' '*indent}<t#{el_html_attributes(el)} hangText='#{ht}'>#{vspaceel}\n"
       end
 
       HTML_TAGS_WITH_BODY=['div', 'script']
@@ -398,6 +400,8 @@ module Kramdown
         target = el.attr['target']
         if target[0] == "&"
           "#{target};"
+        elsif target =~ %r{\A\w+:(?://|.*@)}
+          "<eref#{el_html_attributes(el)}/>"
         else
           "<xref#{el_html_attributes(el)}/>"
         end
@@ -461,7 +465,7 @@ module Kramdown
       }
 
       # XML_RESOURCE_ORG_HOST = ENV["XML_RESOURCE_ORG_HOST"] || "xml.resource.org"
-      XML_RESOURCE_ORG_HOST = ENV["XML_RESOURCE_ORG_HOST"] || "xml2rfc.tools.ietf.org"
+      XML_RESOURCE_ORG_HOST = ENV["XML_RESOURCE_ORG_HOST"] || "xml2rfc.ietf.org"
       XML_RESOURCE_ORG_PREFIX = ENV["XML_RESOURCE_ORG_PREFIX"] ||
                                 "http://#{XML_RESOURCE_ORG_HOST}/public/rfc"
 
@@ -481,6 +485,7 @@ module Kramdown
             puts "Huh: ${fn}" unless sub
             url = "#{XML_RESOURCE_ORG_PREFIX}/#{sub}/#{fn}"
             to_insert = get_and_cache_resource(url)
+            to_insert.scrub! rescue nil # only do this for Ruby >= 2.1
           end
           to_insert.gsub(/<\?xml version=["']1.0["'] encoding=["']UTF-8["']\?>/, '').
             gsub(/(anchor=["'])([0-9])/) { "#{$1}_#{$2}"} # can't start an ID with a number
@@ -549,11 +554,26 @@ module Kramdown
 
       def convert_math(el, indent, opts) # XXX: This is wrong
         el = el.deep_clone
-        el.attr['class'] ||= ''
-        el.attr['class'] += (el.attr['class'].empty? ? '' : ' ') + 'math'
-        type = 'span'
-        type = 'div' if el.options[:category] == :block
-        "<#{type}#{el_html_attributes(el)}>#{escape_html(el.value, :text)}</#{type}>#{type == 'div' ? "\n" : ''}"
+        if el.options[:category] == :block
+          el.attr['artwork-type'] ||= ''
+          el.attr['artwork-type'] += (el.attr['artwork-type'].empty? ? '' : ' ') + 'math'
+          artwork_attr = {}
+          el.attr.each do |k, v|
+            if md = k.match(/\Aartwork-(.*)/)
+              el.attr.delete(k)
+              artwork_attr[md[1]] = v
+            end
+          end
+          result, _s = Open3.capture2("tex2mail -noindent -ragged -by_par -linelength=69", stdin_data: el.value);
+          # warn "*** tex2mail not in path?" unless s.success? -- doesn't have useful status
+          "#{' '*indent}<figure#{el_html_attributes(el)}><artwork#{html_attributes(artwork_attr)}><![CDATA[#{result}#{result =~ /\n\Z/ ? '' : "\n"}]]></artwork></figure>\n"
+
+        else
+          warn "*** no support for inline math in XML2RFCv2"
+          type = 'spanx'
+          attrstring = el_html_attributes_with(el, {"style" => 'verb'})
+          "<#{type}#{attrstring}>#{escape_html(el.value, :text)}</#{type}>"
+        end
       end
 
       ITEM_RE = '\s*(?:"([^"]*)"|([^,]*?))\s*'
